pub struct Error { /* private fields */ }Expand description
Core error struct for the workspace. This hides the internal details of specific errors (like ToolError).
Implementations
Sourceimpl Error
impl Error
Sourcepub fn tool_cmd_failed(code: i32) -> Self
pub fn tool_cmd_failed(code: i32) -> Self
Creates a command failure error associated with tools execution.
Sourcepub fn tool_timeout() -> Self
pub fn tool_timeout() -> Self
Creates a timeout error associated with tools execution.